seqtools.split_sequence_extended_to_weights_with_overhang
=========================================================

.. autofunction:: abjad.tools.seqtools.split_sequence_extended_to_weights_with_overhang
